[PATCH] removed various msdn links

Jonathan Thomas echidnaman at gmail.com
Fri Jan 18 12:37:33 CST 2008


---
 dlls/ddraw/ddraw.c          |    6 ++----
 dlls/msi/action.c           |    7 -------
 dlls/msi/appsearch.c        |    4 +---
 dlls/msi/events.c           |    3 ---
 dlls/msi/format.c           |    3 ---
 dlls/msi/package.c          |    3 +--
 dlls/msvcrt/except.c        |    6 ++----
 dlls/msvcrt/file.c          |    3 +--
 dlls/msvcrt/scanf.h         |    9 +++------
 dlls/ole32/moniker.c        |    2 +-
 dlls/ole32/oleproxy.c       |   19 ++-----------------
 dlls/ole32/stg_prop.c       |   25 +++++++------------------
 dlls/ole32/storage32.c      |    3 +--
 dlls/rpcrt4/cproxy.c        |    5 ++---
 dlls/rpcrt4/ndr_stubless.h  |    2 +-
 dlls/svrapi/svrapi_main.c   |    1 -
 dlls/wined3d/baseshader.c   |    6 +++---
 dlls/wined3d/device.c       |   10 +++-------
 dlls/wined3d/directx.c      |    4 +---
 dlls/wined3d/query.c        |    2 --
 dlls/wined3d/state.c        |    7 +++----
 dlls/wined3d/vertexshader.c |   26 ++------------------------
 dlls/winex11.drv/init.c     |    3 +--
 dlls/winex11.drv/palette.c  |    3 +--
 dlls/winex11.drv/xfont.c    |    1 -
 dlls/ws2_32/socket.c        |    3 +--
 include/d3d9types.h         |    9 ++++-----
 include/ndrtypes.h          |    3 +--
 include/ws2tcpip.h          |    2 +-
 29 files changed, 45 insertions(+), 135 deletions(-)

diff --git a/dlls/ddraw/ddraw.c b/dlls/ddraw/ddraw.c
index e87043a..280cc22 100644
--- a/dlls/ddraw/ddraw.c
+++ b/dlls/ddraw/ddraw.c
@@ -2,7 +2,7 @@
  * Copyright 1997-2000 Marcus Meissner
  * Copyright 1998-2000 Lionel Ulmer
  * Copyright 2000-2001 TransGaming Technologies Inc.
- * Copyright 2006 Stefan Dösinger
+ * Copyright 2006 Stefan D�singer
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -73,9 +73,7 @@ static const DDDEVICEIDENTIFIER2 deviceidentifier =
  * method.
  * The returned interface is AddRef()-ed before it's returned
  *
- * Rules for QueryInterface:
- *  http://msdn.microsoft.com/library/default.asp? \
- *    url=/library/en-us/com/html/6db17ed8-06e4-4bae-bc26-113176cc7e0e.asp
+ * Rules for QueryInterface are included in the documentation at msdn
  *
  * Used for version 1, 2, 4 and 7
  *
diff --git a/dlls/msi/action.c b/dlls/msi/action.c
index 5b940c6..01ecc36 100644
--- a/dlls/msi/action.c
+++ b/dlls/msi/action.c
@@ -18,13 +18,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
-/*
- * Pages I need
- *
-http://msdn.microsoft.com/library/default.asp?url=/library/en-us/msi/setup/installexecutesequence_table.asp
-
-http://msdn.microsoft.com/library/default.asp?url=/library/en-us/msi/setup/standard_actions_reference.asp
- */
 
 #include <stdarg.h>
 
diff --git a/dlls/msi/appsearch.c b/dlls/msi/appsearch.c
index a1e6045..a15a4e4 100644
--- a/dlls/msi/appsearch.c
+++ b/dlls/msi/appsearch.c
@@ -901,9 +901,7 @@ static UINT iterate_appsearch(MSIRECORD *row, LPVOID param)
     return r;
 }
 
-/* http://msdn.microsoft.com/library/en-us/msi/setup/appsearch_table.asp
- * is the best reference for the AppSearch table and how it's used.
- */
+/* MSDN is the best reference for the AppSearch table and how it's used. */
 UINT ACTION_AppSearch(MSIPACKAGE *package)
 {
     static const WCHAR query[] =  {
diff --git a/dlls/msi/events.c b/dlls/msi/events.c
index b85a5c5..0e20e32 100644
--- a/dlls/msi/events.c
+++ b/dlls/msi/events.c
@@ -19,9 +19,6 @@
  */
 
 
-/*
-http://msdn.microsoft.com/library/default.asp?url=/library/en-us/msi/setup/controlevent_overview.asp
-*/
 
 #include <stdarg.h>
 #include <stdio.h>
diff --git a/dlls/msi/format.c b/dlls/msi/format.c
index f56702d..cfa1b0d 100644
--- a/dlls/msi/format.c
+++ b/dlls/msi/format.c
@@ -19,9 +19,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
-/*
-http://msdn.microsoft.com/library/default.asp?url=/library/en-us/msi/setup/msiformatrecord.asp 
- */
 
 #include <stdarg.h>
 #include <stdio.h>
diff --git a/dlls/msi/package.c b/dlls/msi/package.c
index a8d33e0..5c96457 100644
--- a/dlls/msi/package.c
+++ b/dlls/msi/package.c
@@ -334,9 +334,8 @@ done:
 
 /*
  * There are a whole slew of these we need to set
+ *(see msdn)
  *
- *
-http://msdn.microsoft.com/library/default.asp?url=/library/en-us/msi/setup/properties.asp
  */
 static VOID set_installer_properties(MSIPACKAGE *package)
 {
diff --git a/dlls/msvcrt/except.c b/dlls/msvcrt/except.c
index 9af5ff2..d7931b2 100644
--- a/dlls/msvcrt/except.c
+++ b/dlls/msvcrt/except.c
@@ -468,8 +468,7 @@ static LONG WINAPI msvcrt_exception_filter(struct _EXCEPTION_POINTERS *except)
             ret = EXCEPTION_CONTINUE_EXECUTION;
         }
         break;
-    /* According to
-     * http://msdn.microsoft.com/library/en-us/vclib/html/_CRT_signal.asp
+    /* According to MSDN documents
      * the FPE signal handler takes as a second argument the type of
      * floating point exception.
      */
@@ -531,8 +530,7 @@ void msvcrt_free_signals(void)
 
 /*********************************************************************
  *		signal (MSVCRT.@)
- * MS signal handling is described here:
- * http://msdn.microsoft.com/library/en-us/vclib/html/_CRT_signal.asp
+ * MS signal handling is described at msdm.com
  * Some signals may never be generated except through an explicit call to
  * raise.
  */
diff --git a/dlls/msvcrt/file.c b/dlls/msvcrt/file.c
index b4ccdc0..324eab5 100644
--- a/dlls/msvcrt/file.c
+++ b/dlls/msvcrt/file.c
@@ -672,8 +672,7 @@ int CDECL _commit(int fd)
  *		_dup2 (MSVCRT.@)
  * NOTES
  * MSDN isn't clear on this point, but the remarks for _pipe,
- * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/vclib/html/_crt__pipe.asp
- * indicate file descriptors duplicated with _dup and _dup2 are always
+ * indicates file descriptors duplicated with _dup and _dup2 are always
  * inheritable.
  */
 int CDECL MSVCRT__dup2(int od, int nd)
diff --git a/dlls/msvcrt/scanf.h b/dlls/msvcrt/scanf.h
index 7fe3cc4..283ed43 100644
--- a/dlls/msvcrt/scanf.h
+++ b/dlls/msvcrt/scanf.h
@@ -74,8 +74,7 @@
 #endif /* CONSOLE */
 
 /*********************************************************************
- * Implemented based on
- * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/vccore98/html/_crt_format_specification_fields_.2d_.scanf_and_wscanf_functions.asp
+ * Implemented based on MSDN documents
  * Extended by C. Scott Ananian <cananian at alumni.princeton.edu> to handle
  * more types of format spec.
  */
@@ -314,8 +313,7 @@ _FUNCTION_ {
 		    }
                 }
                 break;
-		/* According to
-		 * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/vclib/html/_crt_scanf_type_field_characters.asp
+		/* According to MSDN documents,
 		 * 's' reads a character string in a call to fscanf
 		 * and 'S' a wide character string and vice versa in a
 		 * call to fwscanf. The 'h', 'w' and 'l' prefixes override
@@ -454,8 +452,7 @@ _FUNCTION_ {
 			format++;
 		    }
                     while(*format && (*format != ']')) {
-			/* According to:
-			 * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/vccore98/html/_crt_scanf_width_specification.asp
+			/* According to: MDSN documents
 			 * "Note that %[a-z] and %[z-a] are interpreted as equivalent to %[abcde...z]." */
 			if((*format == '-') && (*(format + 1) != ']')) {
 			    if ((*(format - 1)) < *(format + 1))
diff --git a/dlls/ole32/moniker.c b/dlls/ole32/moniker.c
index cc83d95..8fb6bef 100644
--- a/dlls/ole32/moniker.c
+++ b/dlls/ole32/moniker.c
@@ -50,7 +50,7 @@
 WINE_DEFAULT_DEBUG_CHANNEL(ole);
 
 /* see MSDN docs for IROTData::GetComparisonData, which states what this
- * constant is (http://msdn2.microsoft.com/en-us/library/ms693773.aspx) */
+ * constant is*/
 #define MAX_COMPARISON_DATA 2048
 
 static LONG WINAPI rpc_filter(EXCEPTION_POINTERS *__eptr)
diff --git a/dlls/ole32/oleproxy.c b/dlls/ole32/oleproxy.c
index 55aa3c5..f9f1ac7 100644
--- a/dlls/ole32/oleproxy.c
+++ b/dlls/ole32/oleproxy.c
@@ -2,7 +2,7 @@
  *	OLE32 proxy/stub handler
  *
  *  Copyright 2002  Marcus Meissner
- *  Copyright 2001  Ove Kåven, TransGaming Technologies
+ *  Copyright 2001  Ove K�ven, TransGaming Technologies
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -19,21 +19,6 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  */
 
-/* Documentation on MSDN:
- *
- * (Top level COM documentation)
- * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/dnanchor/html/componentdevelopmentank.asp
- *
- * (COM Proxy)
- * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/com/htm/comext_1q0p.asp
- *
- * (COM Stub)
- * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/com/htm/comext_1lia.asp
- *
- * (Marshal)
- * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/com/htm/comext_1gfn.asp
- *
- */
 
 #include "config.h"
 
@@ -64,7 +49,7 @@ WINE_DEFAULT_DEBUG_CHANNEL(ole);
 
 static ULONG WINAPI RURpcProxyBufferImpl_Release(LPRPCPROXYBUFFER iface);
 
-/* From: http://msdn.microsoft.com/library/en-us/com/cmi_m_4lda.asp
+/* From MSDN documents:
  *
  * The first time a client requests a pointer to an interface on a
  * particular object, COM loads an IClassFactory stub in the server
diff --git a/dlls/ole32/stg_prop.c b/dlls/ole32/stg_prop.c
index 6f4c690..2d02e54 100644
--- a/dlls/ole32/stg_prop.c
+++ b/dlls/ole32/stg_prop.c
@@ -25,8 +25,7 @@
  * License along with this library; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
  *
- * There's a decent overview of property set storage here:
- * http://msdn.microsoft.com/archive/en-us/dnarolegen/html/msdn_propset.asp
+ * There's a decent overview of property set storage at MSDN.com
  * It's a little bit out of date, and more definitive references are given
  * below, but it gives the best "big picture" that I've found.
  *
@@ -68,9 +67,7 @@ static inline StorageImpl *impl_from_IPropertySetStorage( IPropertySetStorage *i
     return (StorageImpl *)((char*)iface - FIELD_OFFSET(StorageImpl, base.pssVtbl));
 }
 
-/* These are documented in MSDN, e.g.
- * http://msdn.microsoft.com/library/en-us/stg/stg/property_set_header.asp
- * http://msdn.microsoft.com/library/library/en-us/stg/stg/section.asp
+/* These are documented in MSDN,
  * but they don't seem to be in any header file.
  */
 #define PROPSETHDR_BYTEORDER_MAGIC      0xfffe
@@ -87,9 +84,7 @@ static inline StorageImpl *impl_from_IPropertySetStorage( IPropertySetStorage *i
 #define CFTAG_FMTID     (-3L)
 #define CFTAG_NODATA      0L
 
-/* The format version (and what it implies) is described here:
- * http://msdn.microsoft.com/library/en-us/stg/stg/format_version.asp
- */
+/* The format version (and what it implies) is described at MSDN */
 typedef struct tagPROPERTYSETHEADER
 {
     WORD  wByteOrder; /* always 0xfffe */
@@ -1421,9 +1416,7 @@ static HRESULT PropertyStorage_ReadFromStream(PropertyStorage_impl *This)
     }
     if (!This->codePage)
     {
-        /* default to Unicode unless told not to, as specified here:
-         * http://msdn.microsoft.com/library/en-us/stg/stg/names_in_istorage.asp
-         */
+        /* default to Unicode unless told not to, as specified at MSDN */
         if (This->grfFlags & PROPSETFLAG_ANSI)
             This->codePage = GetACP();
         else
@@ -2037,9 +2030,7 @@ static HRESULT PropertyStorage_ConstructEmpty(IStream *stm,
         ps->grfFlags = grfFlags;
         if (ps->grfFlags & PROPSETFLAG_CASE_SENSITIVE)
             ps->format = 1;
-        /* default to Unicode unless told not to, as specified here:
-         * http://msdn.microsoft.com/library/en-us/stg/stg/names_in_istorage.asp
-         */
+        /* default to Unicode unless told not to, as specified at MSDN*/
         if (ps->grfFlags & PROPSETFLAG_ANSI)
             ps->codePage = GetACP();
         else
@@ -2507,8 +2498,7 @@ static const WCHAR szDocSummaryInfo[] = { 5,'D','o','c','u','m','e','n','t',
  *
  * NOTES
  * str must be at least CCH_MAX_PROPSTG_NAME characters in length.
- * Based on the algorithm described here:
- * http://msdn.microsoft.com/library/en-us/stg/stg/names_in_istorage.asp
+ * Based on the algorithm described at MSDN.com
  */
 HRESULT WINAPI FmtIdToPropStgName(const FMTID *rfmtid, LPOLESTR str)
 {
@@ -2576,8 +2566,7 @@ HRESULT WINAPI FmtIdToPropStgName(const FMTID *rfmtid, LPOLESTR str)
  *  a format ID, S_OK otherwise.
  *
  * NOTES
- * Based on the algorithm described here:
- * http://msdn.microsoft.com/library/en-us/stg/stg/names_in_istorage.asp
+ * Based on the algorithm described at MSDN.com
  */
 HRESULT WINAPI PropStgNameToFmtId(const LPOLESTR str, FMTID *rfmtid)
 {
diff --git a/dlls/ole32/storage32.c b/dlls/ole32/storage32.c
index a83c729..de4d1bf 100644
--- a/dlls/ole32/storage32.c
+++ b/dlls/ole32/storage32.c
@@ -29,8 +29,7 @@
  *  and manage substorages and streams within a storage object
  *  residing in a compound file object.
  *
- * MSDN
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/stg/stg/istorage_compound_file_implementation.asp
+ * Documentation can be found at MSDN.com
  */
 
 #include <assert.h>
diff --git a/dlls/rpcrt4/cproxy.c b/dlls/rpcrt4/cproxy.c
index 084285a..cd163fe 100644
--- a/dlls/rpcrt4/cproxy.c
+++ b/dlls/rpcrt4/cproxy.c
@@ -1,7 +1,7 @@
 /*
  * COM proxy implementation
  *
- * Copyright 2001 Ove Kåven, TransGaming Technologies
+ * Copyright 2001 Ove K�ven, TransGaming Technologies
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -58,8 +58,7 @@ static const IRpcProxyBufferVtbl StdProxy_Vtbl;
 
 #define ICOM_THIS_MULTI(impl,field,iface) impl* const This=(impl*)((char*)(iface) - offsetof(impl,field))
 
-/* How the Windows stubless proxy thunks work is explained at
- * http://msdn.microsoft.com/library/en-us/dnmsj99/html/com0199.asp,
+/* How the Windows stubless proxy thunks work is explained at msdn,
  * but I'll use a slightly different method, to make life easier */
 
 #if defined(__i386__)
diff --git a/dlls/rpcrt4/ndr_stubless.h b/dlls/rpcrt4/ndr_stubless.h
index 02850d1..1bd5bcd 100644
--- a/dlls/rpcrt4/ndr_stubless.h
+++ b/dlls/rpcrt4/ndr_stubless.h
@@ -23,7 +23,7 @@
 /* there can't be any alignment with the structures in this file */
 #include "pshpack1.h"
 
-/* From http://msdn.microsoft.com/library/default.asp?url=/library/en-us/rpc/rpc/parameter_descriptors.asp */
+/* From MSDN*/
 typedef struct _NDR_PROC_HEADER
 {
     /* type of handle to use:
diff --git a/dlls/svrapi/svrapi_main.c b/dlls/svrapi/svrapi_main.c
index 9649772..364ecfd 100644
--- a/dlls/svrapi/svrapi_main.c
+++ b/dlls/svrapi/svrapi_main.c
@@ -1,6 +1,5 @@
 /*
 * Part of NETAPI on Windows 9x
-* http://msdn.microsoft.com/library/default.asp?url=/library/en-us/stgmgmt/fs/netshareenum.asp
 *
 * Copyright 2006 Konstantin Petrov
 *
diff --git a/dlls/wined3d/baseshader.c b/dlls/wined3d/baseshader.c
index f4c101f..0e1b9df 100644
--- a/dlls/wined3d/baseshader.c
+++ b/dlls/wined3d/baseshader.c
@@ -784,11 +784,11 @@ void shader_dump_param(
     }
 }
 
-/** Shared code in order to generate the bulk of the shader string.
+/* Shared code in order to generate the bulk of the shader string.
     Use the shader_header_fct & shader_footer_fct to add strings
     that are specific to pixel or vertex functions
-    NOTE: A description of how to parse tokens can be found at:
-          http://msdn.microsoft.com/library/default.asp?url=/library/en-us/graphics/hh/graphics/usermodedisplaydriver_shader_cc8e4e05-f5c3-4ec0-8853-8ce07c1551b2.xml.asp */
+    NOTE: A description of how to parse tokens can be found at msdn
+*/
 void shader_generate_main(
     IWineD3DBaseShader *iface,
     SHADER_BUFFER* buffer,
diff --git a/dlls/wined3d/directx.c b/dlls/wined3d/directx.c
index 679dcbb..c43212e 100644
--- a/dlls/wined3d/directx.c
+++ b/dlls/wined3d/directx.c
@@ -1795,9 +1795,7 @@ static HRESULT WINAPI IWineD3DImpl_CheckDeviceFormat(IWineD3D *iface, UINT Adapt
                 break;
         }
     }
-    /* TODO: Check support against more of the WINED3DUSAGE_QUERY_* constants
-     * See http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/IDirect3D9__CheckDeviceFormat.asp
-     * and http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/D3DUSAGE_QUERY.asp */
+    /* TODO: Check support against more of the WINED3DUSAGE_QUERY_* constants, see msdn for details */
     if (Usage & WINED3DUSAGE_QUERY_VERTEXTEXTURE) {
         if (!GL_LIMITS(vertex_samplers)) {
             TRACE_(d3d_caps)("[FAILED]\n");
diff --git a/dlls/wined3d/query.c b/dlls/wined3d/query.c
index 3f02901..b8b7a95 100644
--- a/dlls/wined3d/query.c
+++ b/dlls/wined3d/query.c
@@ -25,8 +25,6 @@
 #include "wined3d_private.h"
 
 /*
- * http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/programmingguide/advancedtopics/Queries.asp
- *
  * Occlusion Queries:
  * http://www.gris.uni-tuebingen.de/~bartz/Publications/paper/hww98.pdf
  * http://oss.sgi.com/projects/ogl-sample/registry/ARB/occlusion_query.txt
diff --git a/dlls/wined3d/state.c b/dlls/wined3d/state.c
index 5e6be54..ce1dfcc 100644
--- a/dlls/wined3d/state.c
+++ b/dlls/wined3d/state.c
@@ -7,7 +7,7 @@
  * Copyright 2004 Christian Costa
  * Copyright 2005 Oliver Stieber
  * Copyright 2006 Henri Verbeet
- * Copyright 2006-2007 Stefan Dösinger for CodeWeavers
+ * Copyright 2006-2007 Stefan D�singer for CodeWeavers
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -1322,7 +1322,7 @@ static void state_pscale(DWORD state, IWineD3DStateBlockImpl *stateblock, WineD3
      * true, the point size is scaled with respect to height of viewport.
      * When set to false point size is in pixels.
      *
-     * http://msdn.microsoft.com/library/en-us/directx9_c/point_sprites.asp
+     * Source: MSDN
      */
 
     /* Default values */
@@ -1453,9 +1453,8 @@ static void state_pointsprite(DWORD state, IWineD3DStateBlockImpl *stateblock, W
 }
 
 static void state_wrap(DWORD state, IWineD3DStateBlockImpl *stateblock, WineD3DContext *context) {
-    /**
+    /*
      http://www.cosc.brocku.ca/Offerings/3P98/course/lectures/texture/
-     http://msdn.microsoft.com/archive/default.asp?url=/archive/en-us/directx9_c/directx/graphics/programmingguide/FixedFunction/Textures/texturewrapping.asp
      http://www.gamedev.net/reference/programming/features/rendererdll3/page2.asp
      Discussion on the ways to turn on WRAPing to solve an OpenGL conversion problem.
      http://www.flipcode.org/cgi-bin/fcmsg.cgi?thread_show=10248
diff --git a/dlls/wined3d/vertexshader.c b/dlls/wined3d/vertexshader.c
index 04b52d9..ee0816c 100644
--- a/dlls/wined3d/vertexshader.c
+++ b/dlls/wined3d/vertexshader.c
@@ -43,30 +43,8 @@ WINE_DEFAULT_DEBUG_CHANNEL(d3d_shader);
 # define TRACE_VSVECTOR(name)
 #endif
 
-/**
- * DirectX9 SDK download
- *  http://msdn.microsoft.com/library/default.asp?url=/downloads/list/directx.asp
- *
- * Exploring D3DX
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/dndrive/html/directx07162002.asp
- *
- * Using Vertex Shaders
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/dndrive/html/directx02192001.asp
- *
- * Dx9 New
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/whatsnew.asp
- *
- * Dx9 Shaders
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/reference/Shaders/VertexShader2_0/VertexShader2_0.asp
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/reference/Shaders/VertexShader2_0/Instructions/Instructions.asp
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/programmingguide/GettingStarted/VertexDeclaration/VertexDeclaration.asp
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/reference/Shaders/VertexShader3_0/VertexShader3_0.asp
- *
- * Dx9 D3DX
- *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/programmingguide/advancedtopics/VertexPipe/matrixstack/matrixstack.asp
- *
- * FVF
- *  http://msdn.microsoft.com/library/en-us/directx9_c/directx/graphics/programmingguide/GettingStarted/VertexFormats/vformats.asp
+/*
+ * DirectX9 SDK download should be available at msdn along with shader/other documentation
  *
  * NVIDIA: DX8 Vertex Shader to NV Vertex Program
  *  http://developer.nvidia.com/view.asp?IO=vstovp
diff --git a/dlls/winex11.drv/init.c b/dlls/winex11.drv/init.c
index bcf60e5..8f60f0b 100644
--- a/dlls/winex11.drv/init.c
+++ b/dlls/winex11.drv/init.c
@@ -251,8 +251,7 @@ INT X11DRV_GetDeviceCaps( X11DRV_PDEVICE *physDev, INT cap )
     case CAPS1:
         FIXME("(%p): CAPS1 is unimplemented, will return 0\n", physDev->hdc );
         /* please see wingdi.h for the possible bit-flag values that need
-           to be returned. also, see
-           http://msdn.microsoft.com/library/ddkdoc/win95ddk/graphcnt_1m0p.htm */
+           to be returned. also, see MSDN.com's documentation*/
         return 0;
     case SIZEPALETTE:
         return palette_size;
diff --git a/dlls/winex11.drv/palette.c b/dlls/winex11.drv/palette.c
index bb6d493..d668abd 100644
--- a/dlls/winex11.drv/palette.c
+++ b/dlls/winex11.drv/palette.c
@@ -44,8 +44,7 @@ WINE_DEFAULT_DEBUG_CHANNEL(palette);
  * because pixel values can be calculated without X server
  * assistance.
  *
- * Windows palette manager is described in the
- * http://premium.microsoft.com/msdn/library/techart/f30/f34/f40/d4d/sa942.htm
+ * Windows palette manager is described in the MDSN documentation
  */
 
 #define NB_RESERVED_COLORS     20   /* number of fixed colors in system palette */
diff --git a/dlls/winex11.drv/xfont.c b/dlls/winex11.drv/xfont.c
index a55e77d..d9fc5ee 100644
--- a/dlls/winex11.drv/xfont.c
+++ b/dlls/winex11.drv/xfont.c
@@ -2404,7 +2404,6 @@ static int XFONT_GetDefResolution( int log_pixels_x, int log_pixels_y )
  *      weight, italics, underlines, strikeouts
  *
  * NOTE: you can experiment with different penalty weights to see what happens.
- * http://premium.microsoft.com/msdn/library/techart/f365/f36b/f37b/d38b/sa8bf.htm
  */
 static UINT XFONT_Match( fontMatch* pfm )
 {
diff --git a/dlls/ws2_32/socket.c b/dlls/ws2_32/socket.c
index 46083c7..823f96d 100644
--- a/dlls/ws2_32/socket.c
+++ b/dlls/ws2_32/socket.c
@@ -881,8 +881,7 @@ static unsigned int ws_sockaddr_ws2u(const struct WS_sockaddr* wsaddr, int wsadd
         const struct WS_sockaddr_in6* win6 = (const struct WS_sockaddr_in6*)wsaddr;
 
         /* Note: Windows has 2 versions of the sockaddr_in6 struct, one with
-         * scope_id, one without. Check:
-         * http://msdn.microsoft.com/library/en-us/winsock/winsock/sockaddr_2.asp
+         * scope_id, one without. Check msdn.
          */
         if (wsaddrlen >= sizeof(struct WS_sockaddr_in6_old)) {
             uaddrlen = sizeof(struct sockaddr_in6);
diff --git a/include/d3d9types.h b/include/d3d9types.h
index 1a0ebec..3858027 100644
--- a/include/d3d9types.h
+++ b/include/d3d9types.h
@@ -226,11 +226,10 @@ typedef enum _D3DDECLUSAGE {
   D3DDECLUSAGE_SAMPLE       = 13     
 } D3DDECLUSAGE;
 
-/* MSDN is quite confussing at this point...
-http://msdn.microsoft.com/archive/default.asp?url=/archive/en-us/directx9_c/directx/graphics/reference/d3d/constants/OTHER_D3D.asp
-says D3DMAX, and D3DMAXDECLUSAGE = D3DDECLUSAGE_DEPTH
-http://msdn.microsoft.com/library/default.asp?url=/archive/en-us/directx9_c_summer_03/directx/graphics/reference/d3d/constants/other_d3d.asp
-says MAXD3D, and D3DDECLUSAGE_SAMPLE
+/* MSDN is quite confussing at this point... one one page it says:
+D3DMAX, and D3DMAXDECLUSAGE = D3DDECLUSAGE_DEPTH
+But another says: 
+MAXD3D, and D3DDECLUSAGE_SAMPLE
 
 So both are defined
 */
diff --git a/include/ndrtypes.h b/include/ndrtypes.h
index 5d932fa..019980e 100644
--- a/include/ndrtypes.h
+++ b/include/ndrtypes.h
@@ -31,8 +31,7 @@ typedef struct
     unsigned short MustFree : 1; /* 0x0002 - server interpreter MUST size this
      *  parameter, other parameters may be skipped, using the value in
      *  NDR_PROC_PARTIAL_OIF_HEADER::constant_server_buffer_size instead. */
-    unsigned short IsPipe : 1; /* 0x0004 - The parameter is a pipe handle. See
-     *  http://msdn.microsoft.com/library/default.asp?url=/library/en-us/rpc/rpc/pipes.asp
+    unsigned short IsPipe : 1; /* 0x0004 - The parameter is a pipe handle. See msdn
      *  for more information on pipes. */
     unsigned short IsIn : 1; /* 0x0008 - The parameter is an input */
     unsigned short IsOut : 1; /* 0x0010 - The parameter is an output */
diff --git a/include/ws2tcpip.h b/include/ws2tcpip.h
index 57a1dc7..2cbacf4 100644
--- a/include/ws2tcpip.h
+++ b/include/ws2tcpip.h
@@ -91,7 +91,7 @@ typedef struct WS(in_addr6)
 } IN6_ADDR, *PIN6_ADDR, *LPIN6_ADDR;
 
 /* check for sockaddr_in6 / sockaddr_in6_old madness:
- * http://msdn.microsoft.com/library/en-us/winsock/winsock/sockaddr_2.asp
+ * (see msdn)
  */
 typedef struct WS(sockaddr_in6)
 {
diff --git a/dlls/wined3d/device.c b/dlls/wined3d/device.c
index 4580c14..63a5b0b 100644
--- a/dlls/wined3d/device.c
+++ b/dlls/wined3d/device.c
@@ -6,7 +6,7 @@
  * Copyright 2003-2004 Raphael Junqueira
  * Copyright 2004 Christian Costa
  * Copyright 2005 Oliver Stieber
- * Copyright 2006-2007 Stefan Dösinger for CodeWeavers
+ * Copyright 2006-2007 Stefan D�singer for CodeWeavers
  * Copyright 2006-2007 Henri Verbeet
  * Copyright 2007 Andrew Riedi
  *
@@ -1862,7 +1862,6 @@ static HRESULT WINAPI IWineD3DDeviceImpl_CreateVertexDeclarationFromFVF(IWineD3D
     return WINED3D_OK;
 }
 
-/* http://msdn.microsoft.com/archive/default.asp?url=/archive/en-us/directx9_c/directx/graphics/programmingguide/programmable/vertexshaders/vscreate.asp */
 static HRESULT WINAPI IWineD3DDeviceImpl_CreateVertexShader(IWineD3DDevice *iface, IWineD3DVertexDeclaration *vertex_declaration, CONST DWORD *pFunction, IWineD3DVertexShader **ppVertexShader, IUnknown *parent) {
     IWineD3DDeviceImpl       *This = (IWineD3DDeviceImpl *)iface;
     IWineD3DVertexShaderImpl *object;  /* NOTE: impl usage is ok, this is a create */
@@ -4040,8 +4039,7 @@ process_vertices_strided(IWineD3DDeviceImpl *This, DWORD dwDestIndex, DWORD dwCo
              * against d3d8 or d3d9!
              */
 
             /* Clipping conditions: From
              * http://msdn.microsoft.com/archive/default.asp?url=/archive/en-us/directx9_c/directx/graphics/programmingguide/fixedfunction/viewportsclipping/clippingvolumes.asp
              *
              * A vertex is clipped if it does not match the following requirements
              * -rhw < x <= rhw
@@ -5749,7 +5747,6 @@ static HRESULT WINAPI IWineD3DDeviceImpl_DrawRectPatch(IWineD3DDevice *iface, UI
     return WINED3D_OK;
 }
 
-/* http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/reference/d3d/interfaces/idirect3ddevice9/DrawTriPatch.asp */
 static HRESULT WINAPI IWineD3DDeviceImpl_DrawTriPatch(IWineD3DDevice *iface, UINT Handle, CONST float* pNumSegs, CONST WINED3DTRIPATCH_INFO* pTriPatchInfo) {
     IWineD3DDeviceImpl *This = (IWineD3DDeviceImpl *)iface;
     TRACE("(%p) Handle(%d) noSegs(%p) tripatch(%p)\n", This, Handle, pNumSegs, pTriPatchInfo);
@@ -6443,8 +6440,7 @@ static HRESULT WINAPI IWineD3DDeviceImpl_SetRenderTarget(IWineD3DDevice *iface,
     but a device must always be associated with a render target
     nope MSDN says that we return invalid call to a null rendertarget with an index of 0
 
-    see http://msdn.microsoft.com/library/default.asp?url=/library/en-us/directx9_c/directx/graphics/programmingguide/AdvancedTopics/PixelPipe/MultipleRenderTarget.asp
-    for more details
+    see msdn documentation for more details
     */
     if (RenderTargetIndex == 0 && pRenderTarget == NULL) {
         FIXME("Trying to set render target 0 to NULL\n");
@@ -4040,8 +4039,7 @@ process_vertices_strided(IWineD3DDeviceImpl *This, DWORD dwDestIndex, DWORD dwCo
              */
 
-            /* Clipping conditions: From
-             * http://msdn.microsoft.com/archive/default.asp?url=/archive/en-us/directx9_c/directx/graphics/programmingguide/fixedfunction/viewportsclipping/clippingvolumes.asp
+            /* Clipping conditions: From msdn documentation
              *
              * A vertex is clipped if it does not match the following requirements
-- 
1.5.2.5


--------------080203000505050100010000--



More information about the wine-patches mailing list